@@ -26,12 +26,12 @@
 #'
 #' @examples 
 #' \donttest{
-#' # download rawinsonde profile from Leba station (WMO ID: 12120) for 20 August 2010 1200 UTC:
+#' # download rawinsonde profile from Vienna (WMO ID: 11035) for 23 August 2011 1200 UTC:
 #' 
-#'   profile = get_sounding(wmo_id = 12120, 
-#'                          yy = 2010,
+#'   profile = get_sounding(wmo_id = 11035, 
+#'                          yy = 2011,
 #'                          mm = 8, 
-#'                          dd = 20, 
+#'                          dd = 23, 
 #'                          hh = 12)
 #'   head(profile)
 #'   
@@ -64,8 +64,10 @@ get_sounding = function(wmo_id, yy, mm, dd, hh, metadata = FALSE) {
   if ((!is.null(sounding_data)) & (ncol(sounding_data[[1]]) > 0)) {
   
     colnames(sounding_data[[1]]) = c("pressure", "altitude", "temp", "dpt",
-                                     "rh", "mixr", "wd", "ws", "thta", "thte", "thtv")
-    sounding_data[[1]] = sounding_data[[1]][, c("pressure", "altitude", "temp", "dpt","wd", "ws")]
+                                     "rh", "mixr", "wd", "ws", "thta", "thte", 
+                                     "thtv")
+    sounding_data[[1]] = sounding_data[[1]][, c("pressure", "altitude", "temp", 
+                                                "dpt","wd", "ws")]
     
     # extra correction for missing entries in the dew oint temperature (only for proper display of the profile):
     sounding_data[[1]]$dpt[is.na(sounding_data[[1]]$dpt) & !is.na(sounding_data[[1]]$temp)] = -273
